@@ -15,14 +15,7 @@ import string
 import ldap
 
 
-__all__ = [
-    'Position',
-    'Department',
-    'SystemAccount',
-    'User',
-    'App',
-    'AppGroup'
-    ]
+__all__ = ["Position", "Department", "SystemAccount", "User", "App", "AppGroup"]
 
 
 class Position(core.LdapObject):
@@ -37,16 +30,14 @@ class Position(core.LdapObject):
 
     def __init__(self, name):
 
-        super(Position, self).__init__('Position', name)
+        super(Position, self).__init__("Position", name)
 
     @staticmethod
     def create(department_name, position_name):
         try:
             department = Department(department_name)
         except IndexError:
-            raise ValueError(
-                "Le département '{}' n'existe pas".format(department_name)
-                )
+            raise ValueError("Le département '{}' n'existe pas".format(department_name))
         else:
             department.add_role(position_name)
 
@@ -54,7 +45,7 @@ class Position(core.LdapObject):
     def occupants(self):
 
         result = []
-        if hasattr(self, 'roleOccupant'):
+        if hasattr(self, "roleOccupant"):
             try:
                 if not isinstance(self.roleOccupant, list):
                     result = [User(self.roleOccupant)]
@@ -66,17 +57,17 @@ class Position(core.LdapObject):
 
     @property
     def department(self):
-        return Department(','.join(self.dn.split(',')[1:]))
+        return Department(",".join(self.dn.split(",")[1:]))
 
     def add_occupant(self, user):
         """Ajouter un utilisateur occupant ce poste"""
-        data = [(ldap.MOD_ADD, 'roleOccupant', user.dn.encode('utf-8'))]
-        core.ldap_conn('modify_s', self.dn, data)
+        data = [(ldap.MOD_ADD, "roleOccupant", user.dn.encode("utf-8"))]
+        core.ldap_conn("modify_s", self.dn, data)
 
     def remove_occupant(self, user):
         """Retirer un utilisateur de la liste des personnes à ce poste"""
-        data = [(ldap.MOD_DELETE, 'roleOccupant', user.dn.encode('utf-8'))]
-        core.ldap_conn('modify_s', self.dn, data)
+        data = [(ldap.MOD_DELETE, "roleOccupant", user.dn.encode("utf-8"))]
+        core.ldap_conn("modify_s", self.dn, data)
 
 
 class Department(core.LdapObject):
@@ -91,7 +82,7 @@ class Department(core.LdapObject):
 
     def __init__(self, name):
 
-        super(Department, self).__init__('Department', name)
+        super(Department, self).__init__("Department", name)
 
     @property
     def roles(self):
@@ -102,14 +93,13 @@ class Department(core.LdapObject):
 
     def add_role(self, name):
         """Créer un rôle dans ce département"""
-        dn = 'cn={},{}'.format(name, self.dn)
-        core.ldap_conn('add_s', dn, [('objectClass', b'organizationalRole')])
+        dn = "cn={},{}".format(name, self.dn)
+        core.ldap_conn("add_s", dn, [("objectClass", b"organizationalRole")])
 
 
 class App(core.LdapObject):
-
     def __init__(self, name):
-        super(App, self).__init__('App', name)
+        super(App, self).__init__("App", name)
 
     @property
     def groups(self):
@@ -117,14 +107,13 @@ class App(core.LdapObject):
 
 
 class AppGroup(core.LdapObject):
-
     def __init__(self, name):
-        super(AppGroup, self).__init__('AppGroup', name)
+        super(AppGroup, self).__init__("AppGroup", name)
 
     @property
     def members(self):
         result = []
-        if hasattr(self, 'memberUid'):
+        if hasattr(self, "memberUid"):
             try:
                 if not isinstance(self.memberUid, list):
                     result = [User(self.memberUid)]
@@ -137,7 +126,7 @@ class AppGroup(core.LdapObject):
     @property
     def app(self):
 
-        return App(','.join(self.dn.split(',')[1:]))
+        return App(",".join(self.dn.split(",")[1:]))
 
 
 class User(core.LdapObject):
@@ -153,9 +142,9 @@ class User(core.LdapObject):
 
     def __init__(self, name):
 
-        super(User, self).__init__('User', name)
+        super(User, self).__init__("User", name)
 
-        if hasattr(self, 'manager'):
+        if hasattr(self, "manager"):
             self.manager = User(self.manager)
 
     @property
@@ -166,26 +155,16 @@ class User(core.LdapObject):
 
     @staticmethod
     def create(
-            name,
-            email,
-            department,
-            registration_number,
-            role,
-            mobile,
-            manager,
-            **kwargs
-            ):
+        name, email, department, registration_number, role, mobile, manager, **kwargs
+    ):
 
         users = User.all()
         for user in users:
-            flag = (
-                user.cn == name or
-                user.uid == email
-                )
+            flag = user.cn == name or user.uid == email
             if flag:
                 raise ValueError(
                     "Un utilisateur avec une de ces informations existe déjà"
-                    )
+                )
         else:
             # on vérifie si le département existe
             try:
@@ -193,17 +172,15 @@ class User(core.LdapObject):
             except IndexError:
                 raise ValueError(
                     "Le département '{}' n'existe pas".format(department.name)
-                    )
+                )
             else:
                 employeeType = [
-                    employeetype for employeetype in department.roles
+                    employeetype
+                    for employeetype in department.roles
                     if employeetype.name == role
-                    ]
+                ]
                 if employeeType and len(employeeType) > 1:
-                    raise ValueError(
-                        "Le rôle '{}' n'est pas unique".format(
-                            role)
-                        )
+                    raise ValueError("Le rôle '{}' n'est pas unique".format(role))
                 elif len(employeeType) == 1:
                     employeeType = employeeType[0]
                 else:
@@ -213,56 +190,53 @@ class User(core.LdapObject):
                     first_name, last_name = name.split()
                 elif len(name.split()) > 2:
                     last_name = name.split()[-1]
-                    first_name = ' '.join(name.split()[:-1])
+                    first_name = " ".join(name.split()[:-1])
                 elif len(name.split()) == 1:
                     last_name = name.split()[0]
-                    first_name = ''
-                first_name = kwargs.get('givenName', first_name)
-                last_name = kwargs.get('sn', last_name)
-                mobile = kwargs.get('mobile', mobile)
-                manager = kwargs.get('manager', manager)
+                    first_name = ""
+                first_name = kwargs.get("givenName", first_name)
+                last_name = kwargs.get("sn", last_name)
+                mobile = kwargs.get("mobile", mobile)
+                manager = kwargs.get("manager", manager)
             data = {
-                'uid': email,
-                'mail': email,
-                'givenName': first_name,
-                'sn': last_name,
-                'cn': name,
-                'employeeType': employeeType.name,
-                'employeeNumber': registration_number,
-                'objectClass': 'inetOrgPerson',
-                }
+                "uid": email,
+                "mail": email,
+                "givenName": first_name,
+                "sn": last_name,
+                "cn": name,
+                "employeeType": employeeType.name,
+                "employeeNumber": registration_number,
+                "objectClass": "inetOrgPerson",
+            }
             if mobile:
-                data['mobile'] = mobile
+                data["mobile"] = mobile
             if manager:
-                data['manager'] = manager
+                data["manager"] = manager
             print(data)
-            data = [
-                (key, value.encode('utf-8')) for key, value in data.items()
-                ]
-            domain = consts.CONFIG['User']['dn']
-            subdomain = kwargs.get('subdomain')
+            data = [(key, value.encode("utf-8")) for key, value in data.items()]
+            domain = consts.CONFIG["User"]["dn"]
+            subdomain = kwargs.get("subdomain")
             if subdomain:
-                domain = 'ou={},{}'.format(subdomain, domain)
+                domain = "ou={},{}".format(subdomain, domain)
             LOGS.logger.info(data)
-            core.ldap_conn('add_s', 'cn={0},{1}'.format(name, domain), data)
+            core.ldap_conn("add_s", "cn={0},{1}".format(name, domain), data)
             # utilisateur créé
             user = User(email)
             # maintenant on le rajoute dans le groupe des occupants du rôle
             employeeType.add_occupant(user)
             # on modifie aussi son uidNumber et son mot de passe
             uidNumbers = [
-                int(user.uidNumber) for user in users
-                if hasattr(user, 'uidNumber')
-                ]
+                int(user.uidNumber) for user in users if hasattr(user, "uidNumber")
+            ]
             uidnumber = max(uidNumbers) + 1
             uidnumber = str(uidnumber)
             data = {
-                'userPassword': email,
-                'gidNumber': '501',
-                'uidNumber': uidnumber,
-                'homeDirectory': '/home/{}'.format(email.split('@')[0]),
-                'objectClass': 'posixAccount'
-                }
+                "userPassword": email,
+                "gidNumber": "501",
+                "uidNumber": uidnumber,
+                "homeDirectory": "/home/{}".format(email.split("@")[0]),
+                "objectClass": "posixAccount",
+            }
             user.update(replace=False, **data)
             user.reset()
 
@@ -270,32 +244,32 @@ class User(core.LdapObject):
     def generate_random_password():
         """Création d'un mot de passe au hasard"""
         choices = string.ascii_letters + string.digits
-        new_password = ''.join(random.sample(choices, random.randint(8, 16)))
+        new_password = "".join(random.sample(choices, random.randint(8, 16)))
         return new_password
 
     @staticmethod
     def verify_auth_token(token):
         """Vérification de la validité d'un jeton de session"""
-        secret_key = list(consts.CONFIG['SECRET_KEY'].keys())[0]
+        secret_key = list(consts.CONFIG["SECRET_KEY"].keys())[0]
         s = Serializer(secret_key)
         try:
             data = s.loads(token)
         except (BadSignature, SignatureExpired, TypeError):
             return None
         else:
-            return User(data['uid'])
+            return User(data["uid"])
 
     def generate_auth_token(self):
         """Création d'un jeton de session valide une heure"""
-        secret_key = list(consts.CONFIG['SECRET_KEY'].keys())[0]
+        secret_key = list(consts.CONFIG["SECRET_KEY"].keys())[0]
         s = Serializer(secret_key, expires_in=3600)
         data = {
             i: j
             for i, j in self.__dict__.items()
-            if i not in ['uid', 'userPassword', 'manager', 'handler']
-            }
-        data['uid'] = self.uid[0]
-        return s.dumps(data).decode('utf-8')
+            if i not in ["uid", "userPassword", "manager", "handler"]
+        }
+        data["uid"] = self.uid[0]
+        return s.dumps(data).decode("utf-8")
 
     def authenticate(self, password):
         """Vérification du mot de passe de l'utilisateur"""
@@ -310,7 +284,7 @@ class User(core.LdapObject):
 
     def passwd(self, old_password, new_password):
         """Modification du mot de passe"""
-        core.ldap_conn('passwd_s', self.dn, old_password, new_password)
+        core.ldap_conn("passwd_s", self.dn, old_password, new_password)
 
     def reset(self):
         """Reset du mot de passe"""
@@ -327,23 +301,21 @@ class User(core.LdapObject):
             action = ldap.MOD_REPLACE
         else:
             action = ldap.MOD_ADD
-        data = [
-            (action, key, value.encode('utf-8'))
-            for key, value in kwargs.items()
-            ]
-        core.ldap_conn('modify_s', self.dn, data)
+        data = [(action, key, value.encode("utf-8")) for key, value in kwargs.items()]
+        core.ldap_conn("modify_s", self.dn, data)
 
     def delete(self):
         Position(self.employeeType).remove_occupant(self)
-        core.ldap_conn('delete_s', self.dn)
+        core.ldap_conn("delete_s", self.dn)
 
     def apps_roles(self):
         """Retourne la liste des rôles spécifiques
         que l'utilisateur possède dans diverses applications"""
         roles = [
-            role for role in AppGroup.all()
+            role
+            for role in AppGroup.all()
             if self.name in [occupant.name for occupant in role.members]
-            ]
+        ]
         return roles
 
     def apps(self):
@@ -356,7 +328,7 @@ class User(core.LdapObject):
 
     def is_blueldap_admin(self):
         for role in self.apps_roles:
-            if role.app.name == 'blueldap' and role.name == 'blueldap_admins':
+            if role.app.name == "blueldap" and role.name == "blueldap_admins":
                 return True
         else:
             return False
@@ -378,31 +350,26 @@ class SystemAccount(core.LdapObject):
 
     def __init__(self, name):
 
-        super(SystemAccount, self).__init__('SystemAccount', name)
+        super(SystemAccount, self).__init__("SystemAccount", name)
 
     @staticmethod
     def create(username, host, email):
         accounts = [
-            SystemAccount(i)
-            for i, j in core.LdapInspector('SystemAccount').search()
-            ]
+            SystemAccount(i) for i, j in core.LdapInspector("SystemAccount").search()
+        ]
         for account in accounts:
             if account.uid == username:
-                raise ValueError(
-                    "Un compte avec les mêmes informations existe déjà"
-                    )
+                raise ValueError("Un compte avec les mêmes informations existe déjà")
         else:
             data = {
-                'uid': username,
-                'objectClass': 'simpleSecurityObject',
-                'userPassword': username,
-                'host': host
-                }
-            data = [
-                (key, value.encode('utf-8')) for key, value in data.items()
-                ]
-            domain = consts.CONFIG['SystemAccount']['dn']
-            core.ldap_conn('add_s', domain, data)
+                "uid": username,
+                "objectClass": "simpleSecurityObject",
+                "userPassword": username,
+                "host": host,
+            }
+            data = [(key, value.encode("utf-8")) for key, value in data.items()]
+            domain = consts.CONFIG["SystemAccount"]["dn"]
+            core.ldap_conn("add_s", domain, data)
             account = SystemAccount(username)
             account.reset()
 
@@ -410,24 +377,24 @@ class SystemAccount(core.LdapObject):
     def generate_random_password():
         """Création d'un mot de passe au hasard"""
         choices = string.ascii_letters + string.digits
-        new_password = ''.join(random.sample(choices, random.randint(8, 16)))
+        new_password = "".join(random.sample(choices, random.randint(8, 16)))
         return new_password
 
     @staticmethod
     def verify_auth_token(token):
         """Vérification de la validité d'un jeton de session"""
-        secret_key = list(consts.CONFIG['SECRET_KEY'].keys())[0]
+        secret_key = list(consts.CONFIG["SECRET_KEY"].keys())[0]
         s = Serializer(secret_key)
         try:
             data = s.loads(token)
         except (BadSignature, SignatureExpired, TypeError):
             return None
         else:
-            return SystemAccount(data['uid'])
+            return SystemAccount(data["uid"])
 
     def generate_auth_token(self, seconds=3600):
         """Création d'un jeton de session valide une heure par défaut"""
-        secret_key = list(consts.CONFIG['SECRET_KEY'].keys())[0]
+        secret_key = list(consts.CONFIG["SECRET_KEY"].keys())[0]
         if not seconds:
             s = JWS(secret_key)
         else:
@@ -435,10 +402,10 @@ class SystemAccount(core.LdapObject):
         data = {
             i: j
             for i, j in self.__dict__.items()
-            if i not in ['uid', 'userPassword', 'handler']
-            }
-        data['uid'] = self.uid[0]
-        return s.dumps(data).decode('utf-8')
+            if i not in ["uid", "userPassword", "handler"]
+        }
+        data["uid"] = self.uid[0]
+        return s.dumps(data).decode("utf-8")
 
     def authenticate(self, password):
         """Vérification du mot de passe de l'utilisateur"""
@@ -453,7 +420,7 @@ class SystemAccount(core.LdapObject):
 
     def passwd(self, old_password, new_password):
         """Modification du mot de passe"""
-        core.ldap_conn('passwd_s', self.dn, old_password, new_password)
+        core.ldap_conn("passwd_s", self.dn, old_password, new_password)
 
     def reset(self):
         """Reset du mot de passe"""
@@ -463,9 +430,10 @@ class SystemAccount(core.LdapObject):
         return new_password
 
     def is_blueldap_admin(self):
-        if self.uid == 'etech':
+        if self.uid == "etech":
             return True
         else:
             return False
 
+
 # EOF
